"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const crypto = require("crypto-promise");
const upath_1 = require("upath");
const FileResource_1 = require("./HTTP/Resources/FileResource");
const isbinaryfile_1 = require("isbinaryfile");
class File {
    constructor(location, workspacePath, options = {
        encoding: 'utf8',
    }) {
        this.location = upath_1.toUnix(location);
        this.encoding = options.encoding || 'utf8';
        this.workspacePath = upath_1.toUnix(workspacePath);
        this.resource = new FileResource_1.default({
            path: this.location.replace(`${this.workspacePath}/`, ''),
            contents: '',
        });
    }
    async write(contents) {
        if (this.isBase64Path() && contents.startsWith('data:')) {
            return await this.write64(contents);
        }
        return await fs.outputFile(this.location, contents, this.encoding);
    }
    async read() {
        if (this.isBase64Asset()) {
            this.resource.contents = await this.read64();
            return;
        }
        this.resource.contents = await fs.readFile(this.location, this.encoding);
    }
    async read64() {
        let fileExtMatch = this.location.match(/\w+$/);
        let fileExt = 'unknown';
        if (fileExtMatch) {
            fileExt = fileExtMatch[0];
        }
        const encoded = await fs.readFile(this.location, { encoding: 'base64' });
        return `data:image/${fileExt};base64,${encoded}`;
    }
    async write64(contents) {
        contents = contents.split(';base64,')[1];
        return await fs.outputFile(this.location, Buffer.from(contents, 'base64'), this.encoding);
    }
    async exists() {
        return await fs.exists(this.location);
    }
    async getShaSum(algorithm = '256') {
        await this.read();
        const buffer = await crypto.hash('sha' + algorithm)(this.resource.contents);
        return buffer.toString('hex');
    }
    isBase64Path() {
        return /themes\/\w*\/assets\//.test(this.location);
    }
    isBase64Asset() {
        return /themes\/\w*\/assets\//.test(this.location) && isbinaryfile_1.isBinaryFileSync(this.location);
    }
}
exports.default = File;
