#!/usr/bin/env node
"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
const clipanion_1 = require("clipanion");
const init_1 = require("./commands/init");
const deploy_1 = require("./commands/deploy");
const wipe_1 = require("./commands/wipe");
const fetch_1 = require("./commands/fetch");
const disable_1 = require("./commands/disable");
const enable_1 = require("./commands/enable");
const config_1 = require("./commands/config");
const packageJson = require("../package.json");
const cli = new clipanion_1.Cli({
    binaryLabel: `Kong Portal CLI Tool`,
    binaryName: `portal`,
    binaryVersion: packageJson.version,
});
class InitCommand extends clipanion_1.Command {
    async execute() {
        await init_1.default(this);
    }
}
InitCommand.usage = clipanion_1.Command.Usage({
    description: 'Initialize a local workspace with a default \`cli.conf.yaml\` configuration file.',
    details: `
    This command will initialize a local workspace with a default \`cli.conf.yaml\` configuration file. \n
    `,
});
__decorate([
    clipanion_1.Command.String({ required: true })
], InitCommand.prototype, "workspace", void 0);
__decorate([
    clipanion_1.Command.Path(`init`)
], InitCommand.prototype, "execute", null);
class DeployCommand extends clipanion_1.Command {
    constructor() {
        super(...arguments);
        this.preserve = false;
        this.watch = false;
        this.disableSSLVerification = false;
        this.ignoreSpecs = false;
        this.skipPath = [];
    }
    async execute() {
        await deploy_1.default(this);
    }
}
DeployCommand.usage = clipanion_1.Command.Usage({
    description: 'Deploy changes made locally under the given workspace upstream.',
    details: `
    This command will deploy local templates upstream from given workspace folder to the same workspace upstream.\n
    If \`-P,--preserve\` option is given a wipe operation will NOT be run first. This will persist the files upstream not found locally.\n
    If \`-W,--watch\` option is given after all the local templates are deployed the deploy will stay running and push any new changes on the filesystem in the workspace.\n
    If \`-D,--disable-ssl-verification\` option is given or \`disable_ssl_verification: true\` is set in \`cli.conf.yaml\`, SSL verification will be disabled to allow for use of self-signed certs.\n
    If \`-I,--ignore-specs\` option is given or \`ignore_specs: true\` in is set in \`cli.conf.yaml\`, the '\\specs' folder will be ignored.\n
    If \`-S,--skip-path\` option is given files or directories that match the path will be skipped during the deploy. The \`--skip-path\` option can be repeated.`,
});
__decorate([
    clipanion_1.Command.String({ required: true })
], DeployCommand.prototype, "workspace", void 0);
__decorate([
    clipanion_1.Command.Boolean(`-P,--preserve`)
], DeployCommand.prototype, "preserve", void 0);
__decorate([
    clipanion_1.Command.Boolean(`-W,--watch`)
], DeployCommand.prototype, "watch", void 0);
__decorate([
    clipanion_1.Command.Boolean(`-D,--disable-ssl-verification`)
], DeployCommand.prototype, "disableSSLVerification", void 0);
__decorate([
    clipanion_1.Command.Boolean(`-I,--ignore-specs`)
], DeployCommand.prototype, "ignoreSpecs", void 0);
__decorate([
    clipanion_1.Command.Array(`-S,--skip-path`)
], DeployCommand.prototype, "skipPath", void 0);
__decorate([
    clipanion_1.Command.Path(`deploy`)
], DeployCommand.prototype, "execute", null);
class FetchCommand extends clipanion_1.Command {
    constructor() {
        super(...arguments);
        this.keepEncode = false;
        this.disableSSLVerification = false;
        this.ignoreSpecs = false;
    }
    async execute() {
        await fetch_1.default(this);
    }
}
FetchCommand.usage = clipanion_1.Command.Usage({
    description: 'Fetches content and themes from the given workspace.',
    details: `
    This command will fetch local templates upstream from given workspace upstream to the workspace folder locally.\n
    The workspace folder must already exist locally with a \`cli.conf.yaml\`.\n
    If \`-K,--keep-encode\` option is given, base64 assets will remain as base64 strings instead of converting to binary files.\n
    If \`-D,--disable-ssl-verification\` option is given or \`disable_ssl_verification: true\` is set in \`cli.conf.yaml\`, SSL verification will be disabled to allow for use of self-signed certs.\n
    If \`-I,--ignore-specs\` option is given or \`ignore_specs: true\` is set in \`cli.conf.yaml\`, the '\\specs' folder will be ignored.`,
});
__decorate([
    clipanion_1.Command.String({ required: true })
], FetchCommand.prototype, "workspace", void 0);
__decorate([
    clipanion_1.Command.Boolean(`-K,--keep-encode`)
], FetchCommand.prototype, "keepEncode", void 0);
__decorate([
    clipanion_1.Command.Boolean(`-D,--disable-ssl-verification`)
], FetchCommand.prototype, "disableSSLVerification", void 0);
__decorate([
    clipanion_1.Command.Boolean(`-I,--ignore-specs`)
], FetchCommand.prototype, "ignoreSpecs", void 0);
__decorate([
    clipanion_1.Command.Path(`fetch`)
], FetchCommand.prototype, "execute", null);
class WipeCommand extends clipanion_1.Command {
    constructor() {
        super(...arguments);
        this.disableSSLVerification = false;
        this.ignoreSpecs = false;
        this.skipPath = [];
    }
    async execute() {
        await wipe_1.default(this);
    }
}
WipeCommand.usage = clipanion_1.Command.Usage({
    description: 'Deletes all content and themes from upstream workspace.',
    details: `
    This command will delete all content and themes from the Upstream Workspace.\n
    If \`-D,--disable-ssl-verification\` option is given or \`disable_ssl_verification: true\` is set in \`cli.conf.yaml\`, SSL verification will be disabled to allow for use of self-signed certs.\n
    If \`-I,--ignore-specs\` option is given or \`ignore_specs: true\` is set in \`cli.conf.yaml\`, the '\\specs' folder will be ignored.\n
    If \`-S,--skip-path\` option is given files or directories that match the path will be ignored. The \`--skip-path\` option can be repeated.`,
});
__decorate([
    clipanion_1.Command.String({ required: true })
], WipeCommand.prototype, "workspace", void 0);
__decorate([
    clipanion_1.Command.Boolean(`-D,--disable-ssl-verification`)
], WipeCommand.prototype, "disableSSLVerification", void 0);
__decorate([
    clipanion_1.Command.Boolean(`-I,--ignore-specs`)
], WipeCommand.prototype, "ignoreSpecs", void 0);
__decorate([
    clipanion_1.Command.Array(`-S,--skip-path`)
], WipeCommand.prototype, "skipPath", void 0);
__decorate([
    clipanion_1.Command.Path(`wipe`)
], WipeCommand.prototype, "execute", null);
class ConfigCommand extends clipanion_1.Command {
    async execute() {
        await config_1.default(this);
    }
}
ConfigCommand.usage = clipanion_1.Command.Usage({
    description: 'Output configuration of the portal on the given workspace, locally.',
});
__decorate([
    clipanion_1.Command.String({ required: true })
], ConfigCommand.prototype, "workspace", void 0);
__decorate([
    clipanion_1.Command.Path(`config`)
], ConfigCommand.prototype, "execute", null);
class EnableCommand extends clipanion_1.Command {
    constructor() {
        super(...arguments);
        this.disableSSLVerification = false;
    }
    async execute() {
        await enable_1.default(this);
    }
}
EnableCommand.usage = clipanion_1.Command.Usage({
    description: 'Enable the portal on the given workspace.',
    details: `
    This command turns on the portal on a existing workspace. Note: \`portal: on\` must be set in the kong.conf.\n
    If \`-D,--disable-ssl-verification\` option is given or \`disable_ssl_verification: true\` is set in \`cli.conf.yaml\`, SSL verification will be disabled to allow for use of self-signed certs.`,
});
__decorate([
    clipanion_1.Command.String({ required: true })
], EnableCommand.prototype, "workspace", void 0);
__decorate([
    clipanion_1.Command.Boolean(`-D,--disable-ssl-verification`)
], EnableCommand.prototype, "disableSSLVerification", void 0);
__decorate([
    clipanion_1.Command.Path(`enable`)
], EnableCommand.prototype, "execute", null);
class DisableCommand extends clipanion_1.Command {
    constructor() {
        super(...arguments);
        this.disableSSLVerification = false;
    }
    async execute() {
        await disable_1.default(this);
    }
}
DisableCommand.usage = clipanion_1.Command.Usage({
    description: 'Disable the portal on the given workspace.',
    details: `
    This command turns off the portal on the given workspace.\n
    If \`-D,--disable-ssl-verification\` option is given or \`disable_ssl_verification: true\` is set in \`cli.conf.yaml\`, SSL verification will be disabled to allow for use of self-signed certs.`,
});
__decorate([
    clipanion_1.Command.String({ required: true })
], DisableCommand.prototype, "workspace", void 0);
__decorate([
    clipanion_1.Command.Boolean(`-D,--disable-ssl-verification`)
], DisableCommand.prototype, "disableSSLVerification", void 0);
__decorate([
    clipanion_1.Command.Path(`disable`)
], DisableCommand.prototype, "execute", null);
class VersionCommand extends clipanion_1.Command {
    async execute() {
        this.context.stdout.write(`${cli.binaryLabel}, version ${cli.binaryVersion}\n`);
    }
}
VersionCommand.usage = clipanion_1.Command.Usage({
    description: 'Display version',
});
__decorate([
    clipanion_1.Command.Path(`--version`),
    clipanion_1.Command.Path(`-v`),
    clipanion_1.Command.Path(`-V`)
], VersionCommand.prototype, "execute", null);
class HelpCommand extends clipanion_1.Command {
    async execute() {
        this.context.stdout.write(this.cli.usage(null));
    }
}
HelpCommand.usage = clipanion_1.Command.Usage({
    description: 'Display help text',
});
__decorate([
    clipanion_1.Command.Path(`--help`),
    clipanion_1.Command.Path(`-h`),
    clipanion_1.Command.Path(`-H`)
], HelpCommand.prototype, "execute", null);
cli.register(InitCommand);
cli.register(DisableCommand);
cli.register(EnableCommand);
cli.register(ConfigCommand);
cli.register(WipeCommand);
cli.register(FetchCommand);
cli.register(DeployCommand);
cli.register(VersionCommand);
cli.register(HelpCommand);
cli.runExit(process.argv.slice(2), Object.assign({}, clipanion_1.Cli.defaultContext));
